﻿using System;
using System.Collections.Generic;
using System.Text;
using Editor.View;
using Editor.Document;
using Editor.Text;

namespace Editor.Commands.Document.Text
{
    public sealed class InsertChar : ICommand, IDocumentCommand
    {
        private char character;
        private IDocument document;

        public IDocument Document
        {
            get { return document; }
        }

        public InsertChar( IDocument document, char character )
        {
            this.character = character;
            this.document = document;
        }
            
        public bool Execute()
        {
            if( document.Selection.MultiIndex ) return false;

            IDocumentRow documentRow = document[document.Selection.StartRow];

            if( !documentRow.Editable ) return false;

            int startIndex = 0;
            int endIndex = 0;
            int index = documentRow.Text.GetVirtualIndex( document.Selection.StartIndex, 
                out startIndex, out endIndex );

            if( document.Selection.StartIndex != startIndex || index < 0 ) return false;

            IAppendableCommand command = document.LastCommand as IAppendableCommand;

            if( command != null && command.CanAppend( documentRow, index ) )
            {
                IText inserted = documentRow.Text.InsertCharacter( index, character );
                command.AppendText( inserted );
            }
            else
            {
                IText text = documentRow.Text.CreateInstance();
                text.InsertGlyph( 0, new CharacterGlyph( character, documentRow.Text.GetInsertStyle( index ) ) );

                return document.ExecuteCommand( new InsertText( document, text ) );
            }

            document.Selection.Change( document.Selection.StartRow, document.Selection.StartIndex + 1,
                document.Selection.StartRow, document.Selection.StartIndex + 1 );

            return true;
        }
    }
}
