﻿using System;
using System.Collections.Generic;
using System.Text;
using Editor.Document;
using Editor.Document.UseCase;
using Editor.Numbering;

namespace Editor.Commands.Document.UseCase
{
    public sealed class AddAlternativeFlow : ICommand, IDocumentCommand
    {
        private UseCaseDocument document;

        public IDocument Document
        {
            get { return document as IDocument; }
        }

        public AddAlternativeFlow( UseCaseDocument document )
        {
            this.document = document;
        }

        public bool Execute()
        {
            if( document.Selection.MultiRow ) return false;

            TemplateRow templateRow = document[document.Selection.StartRow] as TemplateRow;

            if( templateRow is StepRow )
            {
                int sectionRow = document.FindSection( ESectionType.AlternativeFlow );

                if( sectionRow == -1 ) return false;

                TemplateRow alternativeFlowSection = document[sectionRow] as TemplateRow;

                alternativeFlowSection.Add( new AlternativeFlow( new DefaultNumbering("A"), "New Alternative Flow", templateRow as StepRow ) );

                return true;
            }

            return false;
        }
    }
}
