﻿using System;
using System.Collections.Generic;
using System.Text;
using Editor.Numbering;
using Editor.Text;
using Editor.View;
using System.Drawing;

namespace Editor.Document.UseCase
{
    public abstract class Flow : TemplateRow, INumbered
    {
        protected string name;
        protected INumbering numbering;

        public abstract string CurrentNumber { get; }

        public override bool Editable
        {
            get { return true; }
        }

        public bool EqualNumberIndent
        {
            get { return false; }
        }

        public override bool Formattable 
        {
            get { return false; } 
        }

        public bool LevelChanging
        {
            get { return false; }
        }

        public override bool Removable
        {
            get { return true; }
        }

        public abstract string LongestNumber { get; }

        public INumbering Numbering
        {
            get { return numbering; }
        }

        public short NumberingStyle
        {
            get { return (short)EDefaultStyles.FlowNumbering; }
        }

        public event EventHandler NumberingChanged;

        public Flow( INumbering numbering, string name ) : base()
        {
            this.name = name;   
            this.numbering = numbering;

            numbering.ObjectChanged += OnNumberingChanged;

            text.InsertString( 0, name );
            text.ChangeStyle( 0, name.Length, (short)EDefaultStyles.FlowName );
        }

        public override TemplateRow CreateNewRow()
        {
            return null;
        }

        public override string ToString()
        {
            return string.Concat( CurrentNumber, " ", text.ToString() );
        }

        protected void NumberingChangedEvent( object sender, EventArgs eventArgs )
        {
            OnNumberingChanged( sender, eventArgs );
        }

        private void OnNumberingChanged( object sender, EventArgs eventArgs )
        {
            if( NumberingChanged != null ) NumberingChanged( sender, eventArgs );

            ObjectChangedEvent( sender, eventArgs );
        }
    }
}
