﻿using System;
using System.Collections.Generic;
using System.Text;
using System.ComponentModel;

namespace Editor.Project
{
    public sealed class DictionaryWord : INotifyPropertyChanged, IChangeHandler
    {
        private EventArgs changeArgs;
        private string definition;
        private string name;
        private bool objectChanging;
        private BindingList<Variation> variations;

        public bool Changing
        {
            get { return objectChanging; }
        }

        public string Definition
        {
            get { return definition; }
            set 
            { 
                definition = value; 
            }
        }

        public string Name
        {
            get { return name; }
            set
            {
                name = value;

                if( PropertyChanged != null )
                    PropertyChanged( this, new PropertyChangedEventArgs("Name") );

                ObjectChangedEvent( this, EventArgs.Empty );
            }
        }

        public BindingList<Variation> Variations
        {
            get { return variations; }
            set 
            {
                variations = value;

                ObjectChangedEvent( this, EventArgs.Empty );
            }
        }

        public event EventHandler ObjectChanged;
        public event EventHandler ObjectChanging;
        public event PropertyChangedEventHandler PropertyChanged;

        public DictionaryWord( string name, string definition )
        {
            changeArgs = null;
            this.definition = definition;
            this.name = name;
            objectChanging = false;
            variations = new BindingList<Variation>();

            variations.Add( new Variation( string.Empty ) );
            variations.Add( new Variation( string.Empty ) );
            variations.Add( new Variation( string.Empty ) );
            variations.Add( new Variation( string.Empty ) );
            variations.Add( new Variation( string.Empty ) );
            variations.Add( new Variation( string.Empty ) );
            variations.Add( new Variation( string.Empty ) );
            variations.Add( new Variation( string.Empty ) );
            variations.Add( new Variation( string.Empty ) );
            variations.Add( new Variation( string.Empty ) );
            variations.Add( new Variation( string.Empty ) );
            variations.Add( new Variation( string.Empty ) );
        }

        public void BeginChange()
        {
            if( !objectChanging )
            {
                objectChanging = true;
                changeArgs = null;

                if( ObjectChanging != null ) ObjectChanging( this, EventArgs.Empty );
            }
        }

        public BindingList<Variation> CloneVariations()
        {
            BindingList<Variation> clonedVariations = new BindingList<Variation>();

            for( int i = 0; i < variations.Count; i++ ) clonedVariations.Add( variations[i].Clone() );

            return clonedVariations;
        }

        public void EndChange( bool discardEvent )
        {
            if( objectChanging )
            {
                objectChanging = false;

                if( !discardEvent && changeArgs != null ) ObjectChangedEvent( this, changeArgs ); 
            }
        }

        public Delegate[] GetReferences()
        {
            return ObjectChanged.GetInvocationList();
        }

        public override string ToString()
        {
            return name;
        }

        private void ObjectChangedEvent( object sender, EventArgs eventArgs )
        {
            if( objectChanging ) 
            {
                changeArgs = eventArgs;
                return;
            }

            if( ObjectChanged != null ) ObjectChanged( sender, eventArgs );
        }
    }
}
