﻿using System;
using System.Collections.Generic;
using System.Text;
using Editor.Document.UseCase;
using Editor.Numbering;
using Editor.Document;

namespace Editor.Text.UseCase
{
    public sealed class StepGlyph : Glyph, IChangeHandler
    {
        private string stepLabel;
        private StepRow stepRow;

        public bool Changing
        {
            get { throw new NotImplementedException(); ; }
        }

        public override int CharacterLength 
        {
            get { return stepLabel.Length; }
        }

        public StepRow Step
        {
            get { return stepRow; }
            set 
            {
                stepRow.ObjectChanged -= OnRowChanged;

                stepRow = value;

                stepRow.ObjectChanged += OnRowChanged;

                OnRowChanged( stepRow, EventArgs.Empty );
            }
        }

        public override bool StyleChanging
        {
            get { return false; }
        }

        public override bool StyleCopying
        {
            get { return false; }
        }

        public override EGlyphType Type
        {
            get { return EGlyphType.Step; }
        }

        public event EventHandler ObjectChanged;
        public event EventHandler ObjectChanging;

        public StepGlyph( StepRow stepRow )
        {
            this.stepRow = stepRow;
            style = (short)EDefaultStyles.StepLink;

            stepLabel = CreateLabel();

            stepRow.ObjectChanged += OnRowChanged;
        }

        public void BeginChange()
        {
            throw new NotImplementedException();
        }

        public override Glyph Clone()
        {
            return new StepGlyph( stepRow );
        }

        public void EndChange( bool discardEvent )
        {
            throw new NotImplementedException();
        }

        public Delegate[] GetReferences()
        {
            return ObjectChanged.GetInvocationList();
        }

        public override char GetCharAt( int index )
        {
            return stepLabel[index];
        }

        public override string ToString()
        {
            return stepLabel.ToString();
        }

        private string CreateLabel()
        {
            StringBuilder buffer = new StringBuilder();

            buffer.Append( (stepRow.Parent as INumbered).CurrentNumber );
            buffer.Append('.');
            buffer.Append( (stepRow as INumbered).CurrentNumber );

            return buffer.ToString();
        }

        private void OnRowChanged( object sender, EventArgs eventArgs ) 
        {
            stepLabel = CreateLabel();

            if( ObjectChanged != null ) ObjectChanged( sender, eventArgs );
        }
    }
}
