﻿using System;
using System.Collections.Generic;
using System.Text;
using System.Windows.Forms;
using Editor.Document;
using Editor.Text;

namespace UseCaseTool.Controls
{
    public class GlyphsListBox : ListBox
    {
        protected IDocumentRow documentRow;

        public IDocumentRow DocumentRow 
        {
            get { return documentRow; }
            set 
            {
                if( documentRow != null ) documentRow.ObjectChanged -= OnDocumentChanged;

                documentRow = value;

                if( documentRow == null ) Items.Clear();
                else
                {
                    documentRow.ObjectChanged += OnDocumentChanged;
                    Repopulate();
                }
            }
        }

        public GlyphsListBox( IDocumentRow documentRow )
        {
            this.documentRow = documentRow;
            if( documentRow != null ) 
            {
                documentRow.ObjectChanged += OnDocumentChanged;
                Repopulate();
            }
        }

        protected virtual void OnDocumentChanged( object sender, EventArgs eventArgs )
        {
            Repopulate();
        }

        public void Repopulate()
        {
            if( documentRow == null ) return;

            BeginUpdate();

            Items.Clear();

            for( int i = 0; i < documentRow.Text.VirtualLength; i++ )
            {
                Glyph glyph = documentRow.Text[i];

                if( ApplyFilter( glyph ) ) Items.Add( new ListBoxTextGlyph( glyph ) );
            }

            EndUpdate();
        }

        protected virtual bool ApplyFilter( Glyph glyph )
        {
            return true;
        }
    }
}
