﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using Editor.Project;

namespace UseCaseTool.Forms
{
    public partial class ActorForm : Form
    {
        private Actor actor;
        private BindingList<Variation> variations;

        public Actor Actor
        {
            get { return actor; }
        }

        public ActorForm( Actor actor )
        {
            this.actor = actor;

            InitializeComponent();

            nameTB.Text = actor.ItemName;
            goalsTB.Text = actor.Goals;
            descriptionTB.Text = actor.Description;
            variations = actor.CloneVariations();
        }

        private void confirmBN_Click(object sender, EventArgs e)
        {
            if( nameTB.Text.Trim() == string.Empty )
            {
                MessageBox.Show( "Name cannot be empty", "Warning", MessageBoxButtons.OK, 
                    MessageBoxIcon.Warning );
                return;
            }

            actor.ItemName = nameTB.Text.Trim();
            actor.Goals = goalsTB.Text.Trim();
            actor.Description = descriptionTB.Text.Trim();
            actor.Variations = variations;

            DialogResult = DialogResult.OK;
        }

        private void variationsBN_Click(object sender, EventArgs e)
        {
            BindingList<Variation> clonedVariations = new BindingList<Variation>();
            for( int i = 0; i < variations.Count; i++ ) clonedVariations.Add( variations[i].Clone() );

            VariationsEditorForm variationsForm = new VariationsEditorForm( clonedVariations );

            DialogResult dialogResult = variationsForm.ShowDialog();

            if( dialogResult == DialogResult.OK )
            {
                variations = variationsForm.Variations;
            }
        }

        private void cancelBN_Click(object sender, EventArgs e)
        {
            DialogResult = DialogResult.Cancel;
        }
    }
}
