﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using Editor.Text;
using System.Drawing.Text;

namespace UseCaseTool.Forms
{
    public partial class StylesEditorForm : Form
    {
        private IStyle style;

        public IStyle Style
        {
            get { return style; }
        }

        public StylesEditorForm( IStyle style )
        {
            InitializeComponent();

            this.style = style;

            InstalledFontCollection installedFontCollection = new InstalledFontCollection();
            FontFamily[] fontFamilies = installedFontCollection.Families;

            for( int i = 0; i < fontFamilies.Length; i++ )
                installedFontsLB.Items.Add( fontFamilies[i].Name );

            nameTB.Text = style.Name;
            boldCHB.Checked = style.Bold;
            italicCHB.Checked = style.Italic;
            strikeoutCHB.Checked = style.Strikeout;
            underlineCHB.Checked = style.Underline;
            fontSizeTB.Text = style.Size.ToString();
            backColorBN.BackColor = style.BackColor;
            textColorBN.BackColor = style.TextColor;

            for( int i = 0; i < installedFontsLB.Items.Count; i++ )
            {
                string item = installedFontsLB.Items[i].ToString();

                if( string.Equals( item, style.FontFamily.Name ) ) 
                {
                    installedFontsLB.SelectedIndex = i;
                    return;
                }
            }
        }

        private void textColorBN_Click(object sender, EventArgs e)
        {
            textCD.ShowDialog();
            textColorBN.BackColor = textCD.Color;
        }

        private void backColorBN_Click(object sender, EventArgs e)
        {
            backgroundCD.ShowDialog();
            backColorBN.BackColor = backgroundCD.Color;
        }

        private void confirmBN_Click(object sender, EventArgs e)
        {
            if( nameTB.Text.Trim() == string.Empty ) 
            {
                MessageBox.Show( "Style name cannot be empty", "Warning", MessageBoxButtons.OK,
                    MessageBoxIcon.Warning );
                return;
            }

            if( installedFontsLB.SelectedIndex < 0 ) 
            {
                MessageBox.Show( "No font selected", "Warning", MessageBoxButtons.OK, MessageBoxIcon.Warning );
                return;
            }

            if( fontSizeTB.Text.Trim() == string.Empty ) 
            {
                MessageBox.Show( "Style name cannot be empty", "Warning", MessageBoxButtons.OK,
                    MessageBoxIcon.Warning );
                return;
            }

            float fontSize = 0;

            if( !float.TryParse( fontSizeTB.Text.Trim(), out fontSize) )
            {
                MessageBox.Show( "Invalid font size", "Warning", MessageBoxButtons.OK,
                    MessageBoxIcon.Warning );
                return;          
            }

            style.Name = nameTB.Text.Trim();
            style.FontFamily = new FontFamily( installedFontsLB.Items[installedFontsLB.SelectedIndex].ToString() );
            style.Bold = boldCHB.Checked;
            style.Italic = italicCHB.Checked;
            style.Strikeout = strikeoutCHB.Checked;
            style.Underline = underlineCHB.Checked;
            style.Size = fontSize;
            style.BackColor = backColorBN.BackColor;
            style.TextColor = textColorBN.BackColor;

            DialogResult = DialogResult.OK;
        }

        private void fontSizesLB_SelectedIndexChanged(object sender, EventArgs e)
        {
            if( fontSizesLB.SelectedIndex < 0 ) return;

            fontSizeTB.Text = fontSizesLB.SelectedItem.ToString();
        }
    }
}
